searchData={"content_type":"text/markdown","items":[{"doc":"Task to build the tableau site","ref":"Mix.Tasks.Tableau.Build.html","title":"mix tableau.build","type":"task"},{"doc":"Starts the tableau dev server","ref":"Mix.Tasks.Tableau.Server.html","title":"mix tableau.server","type":"task"},{"doc":"Markdown files (with YAML frontmatter) in the configured pages directory will be automatically compiled into Tableau pages.\n\nCertain frontmatter keys are required and all keys are passed as options to the `Tableau.Page`.","ref":"Tableau.PageExtension.html","title":"Tableau.PageExtension","type":"module"},{"doc":"Frontmatter is compiled with `yaml_elixir` and all keys are converted to atoms.\n\n* `:title` - The title of the page\n* `:permalink` - The permalink of the page.\n* `:layout` - A string representation of a Tableau layout module.","ref":"Tableau.PageExtension.html#module-options","title":"Options - Tableau.PageExtension","type":"module"},{"doc":"```yaml\nid: \"GettingStarted\"\ntitle: \"Getting Started\"\npermalink: \"/docs/:title\"\nlayout: \"ElixirTools.PageLayout\"\n```","ref":"Tableau.PageExtension.html#module-example","title":"Example - Tableau.PageExtension","type":"module"},{"doc":"The permalink is a string with colon prefixed template variables.\n\nThese variables will be swapped with the corresponding YAML Frontmatter key, with the result being piped through `to_string/1`.","ref":"Tableau.PageExtension.html#module-permalink","title":"Permalink - Tableau.PageExtension","type":"module"},{"doc":"- `:enabled` - boolean - Extension is active or not.\n- `:dir` - string - Directory to scan for markdown files. Defaults to `_pages`\n- `:permalink` - string - Default output path for pages. Accepts `:title` as a replacement keyword, replaced with the page's provided title. If a page has a `:permalink` provided, that will override this value _for that page_.\n- `:layout` - string - Elixir module providing page layout for pages. Default is nil.\n\n#","ref":"Tableau.PageExtension.html#module-configuration","title":"Configuration - Tableau.PageExtension","type":"module"},{"doc":"```elixir\nconfig :tableau, Tableau.PageExtension,\n  enabled: true,\n  dir: \"_docs\",\n  permalink: \"/docs/:title\",\n  layout: \"MyApp.PageLayout\"\n```","ref":"Tableau.PageExtension.html#module-example","title":"Example - Tableau.PageExtension","type":"module"},{"doc":"","ref":"Tableau.PageExtension.html#run/1","title":"Tableau.PageExtension.run/1","type":"function"},{"doc":"Generate a sitemap.xml for your site, for improved search-engine indexing.","ref":"Tableau.SitemapExtension.html","title":"Tableau.SitemapExtension","type":"module"},{"doc":"- `:enabled` - boolean - Extension is active or not.\n\n#","ref":"Tableau.SitemapExtension.html#module-configuration","title":"Configuration - Tableau.SitemapExtension","type":"module"},{"doc":"```elixir\nconfig :tableau, Tableau.SitemapExtension,\n  enabled: true,\n```","ref":"Tableau.SitemapExtension.html#module-example","title":"Example - Tableau.SitemapExtension","type":"module"},{"doc":"Any page may add attributes to its sitemap ` ` entry by adding a `sitemap` entry, with a map of elements to add\n\n#","ref":"Tableau.SitemapExtension.html#module-custom-attributes","title":"Custom attributes - Tableau.SitemapExtension","type":"module"},{"doc":"```yaml\ntitle: \"Some Page\"\nsitemap:\n  priority: 0.8\n  changefreq: hourly\n```\n\n### `Tableau.Page`\n\n```elixir\ndefmodule MySite.AboutPage do\n  use Tableau.Page,\n    layout: MySite.RootLayout,\n    permalink: \"/about\",\n    sitemap: %{priority: 0.8, changefreq: \"monthly\"}\n\n  # ...\nend\n```\n\nGenerated sitemap is stored in the root of your site, at /sitemap.xml.\n\nFor more information about sitemaps, see  .","ref":"Tableau.SitemapExtension.html#module-frontmatter","title":"Frontmatter - Tableau.SitemapExtension","type":"module"},{"doc":"","ref":"Tableau.SitemapExtension.html#run/1","title":"Tableau.SitemapExtension.run/1","type":"function"},{"doc":"","ref":"Tableau.html","title":"Tableau","type":"module"},{"doc":"* `:include_dir` - string - Directory that is just copied to the output directory. Defaults to `extra`.\n* `:timezone` - string - Timezone to use when parsing date times. Defaults to `Etc/UTC`.\n* `:base_path - string - Development server root.  Defaults to '/'.\n* `:url` - string (required) - The URL of your website.\n* `:markdown` - keyword\n    * `:mdex` - keyword - Options to pass to `MDEx.to_html/2`","ref":"Tableau.html#module-global-site-configuration","title":"Global Site Configuration - Tableau","type":"module"},{"doc":"Component to connect to the development server via websocket to broadcast that the page should reload.\n\nBy default, connects to `'ws://' + location.host + '/ws'`.\n\nSee `WebDevUtils` for configuration options.","ref":"Tableau.html#live_reload/1","title":"Tableau.live_reload/1","type":"function"},{"doc":"Convert markdown content to HTML using `MDEx.to_html/2`.\n\nWill use the globally configured options, but you can also pass it overrides.","ref":"Tableau.html#markdown/2","title":"Tableau.markdown/2","type":"function"},{"doc":"Helper functions for Tableau documents.","ref":"Tableau.Document.Helper.html","title":"Tableau.Document.Helper","type":"module"},{"doc":"A macro for rendering nested content within a layout.\n\nPlease see the `Tableau.Layout` docs for more info.","ref":"Tableau.Document.Helper.html#render/1","title":"Tableau.Document.Helper.render/1","type":"macro"},{"doc":"A tableau layout.\n\nLayouts will render `@inner_content` using the `Tableau.Document.Helper.render/1` macro.\n\n```elixir\ndefmodule MySite.SidebarLayout do\n  use Tableau.Page,\n    layout: MySite.RootLayout\n\n  def template(assigns) do\n    \"\"\"\n     \n       \n       \n     \n\n     \n       \n     \n    \"\"\"\n  end\nend\n```","ref":"Tableau.Layout.html","title":"Tableau.Layout","type":"behaviour"},{"doc":"The layout template.","ref":"Tableau.Layout.html#c:template/1","title":"Tableau.Layout.template/1","type":"callback"},{"doc":"","ref":"Tableau.Layout.html#t:assigns/0","title":"Tableau.Layout.assigns/0","type":"type"},{"doc":"","ref":"Tableau.Layout.html#t:template/0","title":"Tableau.Layout.template/0","type":"type"},{"doc":"A tableau page.\n\nA page is a basic unit of a static site.\n\n```elixir\ndefmodule MySite.HomePage do\n  use Tableau.Page,\n    layout: MySite.RootLayout,\n    permalink: \"/\"\n\n  def template(assigns) do\n    \"\"\"\n     My Site \n\n     \n      Welcome to my site!\n     \n    \"\"\"\n  end\nend\n```","ref":"Tableau.Page.html","title":"Tableau.Page","type":"behaviour"},{"doc":"The page template.","ref":"Tableau.Page.html#c:template/1","title":"Tableau.Page.template/1","type":"callback"},{"doc":"","ref":"Tableau.Page.html#t:assigns/0","title":"Tableau.Page.assigns/0","type":"type"},{"doc":"","ref":"Tableau.Page.html#t:template/0","title":"Tableau.Page.template/0","type":"type"},{"doc":"YAML files and Elixir scripts (.exs) in the configured directory will be automatically parsed/executed and made available in an `@data` assign in your templates.\n\nElixir scripts will be executed and the last expression returned as the data.","ref":"Tableau.DataExtension.html","title":"Tableau.DataExtension","type":"module"},{"doc":"- `:enabled` - boolean - Extension is active or not.\n- `:dir` - string - Directory to scan for data files. Defaults to `_data`\n\n#","ref":"Tableau.DataExtension.html#module-configuration","title":"Configuration - Tableau.DataExtension","type":"module"},{"doc":"```elixir\nconfig :tableau, Tableau.DataExtension,\n  enabled: true,\n  dir: \"_facts\"\n```\n\n \n\n#","ref":"Tableau.DataExtension.html#module-example","title":"Example - Tableau.DataExtension","type":"module"},{"doc":"```yaml\n# _facts/homies.yaml\n- name: Mitch\n- name: Jimbo\n- name: Bobby\n```\n\n```heex\n \n   \n     \n   \n \n```\n\n#","ref":"Tableau.DataExtension.html#module-yaml","title":"YAML - Tableau.DataExtension","type":"module"},{"doc":"```elixir\n# _facts/homies.exs\nresp = Req.get!(\"https://example.com/homies\")\n\nresp.body[\"homies\"]\n```\n\n```heex\n \n   \n     \n   \n \n```","ref":"Tableau.DataExtension.html#module-elixir","title":"Elixir - Tableau.DataExtension","type":"module"},{"doc":"","ref":"Tableau.DataExtension.html#run/1","title":"Tableau.DataExtension.run/1","type":"function"},{"doc":"A tableau extension.\n\nAn extension can be used to generate other kinds of content.","ref":"Tableau.Extension.html","title":"Tableau.Extension","type":"behaviour"},{"doc":"* `:key` - The key in which the extensions configuration and data is loaded.\n* `:type` - The type of extension. See below for a description.\n* `:priority` - An integer used for ordering extensions of the same type.\n* `:enabled` - Whether or not to enable the extension. Defaults to true, and can be configured differently based on the extension.","ref":"Tableau.Extension.html#module-options","title":"Options - Tableau.Extension","type":"behaviour"},{"doc":"There are currently the following extension types:\n\n- `:pre_build` - executed before tableau builds your site and writes anything to disk.\n- `:post_write` - executed after tableau builds your site and writes everything to disk.","ref":"Tableau.Extension.html#module-types","title":"Types - Tableau.Extension","type":"behaviour"},{"doc":"```elixir\ndefmodule MySite.PostsExtension do\n  use Tableau.Extension, key: :posts, type: :pre_build, priority: 300\n\n  def run(token) do\n    posts = Path.wildcard(\"_posts/**/*.md\")\n\n    for post   Markdown.render()\n      |> then(&File.write(Path.join(Path.rootname(post), \"index.html\"), &1))\n    end\n\n    {:ok, token}\n  end\nend\n```","ref":"Tableau.Extension.html#module-example","title":"Example - Tableau.Extension","type":"behaviour"},{"doc":"The extension entry point.\n\nThe function is passed a token and can return a new token with new data loaded into it.","ref":"Tableau.Extension.html#c:run/1","title":"Tableau.Extension.run/1","type":"callback"},{"doc":"","ref":"Tableau.Extension.html#t:token/0","title":"Tableau.Extension.token/0","type":"type"},{"doc":"Markdown files (with YAML frontmatter) in the configured posts directory will be automatically compiled into Tableau pages.\n\nCertain frontmatter keys are required and all keys are passed as options to the `Tableau.Page`.","ref":"Tableau.PostExtension.html","title":"Tableau.PostExtension","type":"module"},{"doc":"Frontmatter is compiled with `yaml_elixir` and all keys are converted to atoms.\n\n* `:title` - The title of the post. Falls back to the first ` ` tag if present in the body.\n* `:permalink` - The permalink of the post. `:title` will be replaced with the posts title and non alphanumeric characters removed. Optional.\n* `:date` - A string representation of an Elixir `NaiveDateTime`, often presented as a `sigil_N`. This will be converted to your configured timezone.\n* `:layout` - A string representation of a Tableau layout module.","ref":"Tableau.PostExtension.html#module-options","title":"Options - Tableau.PostExtension","type":"module"},{"doc":"```yaml\nid: \"Update.Volume3\"\ntitle: \"The elixir-tools Update Vol. 3\"\npermalink: \"/news/:title\"\ndate: \"~N[2023-09-19 01:00:00]\"\nlayout: \"ElixirTools.PostLayout\"\n```","ref":"Tableau.PostExtension.html#module-example","title":"Example - Tableau.PostExtension","type":"module"},{"doc":"The permalink is a string with colon prefixed template variables.\n\nThese variables will be swapped with the corresponding YAML Frontmatter key, with the result being piped through `to_string/1`.\n\nIn addition, there are `:year`, `:month`, and `:day` template variables.","ref":"Tableau.PostExtension.html#module-permalink","title":"Permalink - Tableau.PostExtension","type":"module"},{"doc":"- `:enabled` - boolean - Extension is active or not.\n- `:dir` - string - Directory to scan for markdown files. Defaults to `_posts`\n- `:future` - boolean - Show posts that have dates later than the current timestamp, or time at which the site is generated.\n- `:permalink` - string - Default output path for posts. Accepts `:title` as a replacement keyword, replaced with the post's provided title. If a post has a `:permalink` provided, that will override this value _for that post_.\n- `:layout` - string - Elixir module providing page layout for posts. Default is nil\n\n#","ref":"Tableau.PostExtension.html#module-configuration","title":"Configuration - Tableau.PostExtension","type":"module"},{"doc":"```elixir\nconfig :tableau, Tableau.PostExtension,\n  enabled: true,\n  dir: \"_articles\",\n  future: true,\n  permalink: \"/articles/:year/:month/:day/:title\",\n  layout: \"MyApp.PostLayout\"\n```","ref":"Tableau.PostExtension.html#module-example","title":"Example - Tableau.PostExtension","type":"module"},{"doc":"","ref":"Tableau.PostExtension.html#run/1","title":"Tableau.PostExtension.run/1","type":"function"},{"doc":"Generate RSS data and write to `_site/feed.xml`.","ref":"Tableau.RSSExtension.html","title":"Tableau.RSSExtension","type":"module"},{"doc":"- `:enabled` - boolean - Extension is active or not.\n- `:title` - string (required) - Title of your feed.\n- `:description` - string (required) - Description of your feed.\n- `:language` - string - Language to use in the ` ` tag. Defaults to \"en-us\"\n\n#","ref":"Tableau.RSSExtension.html#module-configuration","title":"Configuration - Tableau.RSSExtension","type":"module"},{"doc":"```elixir\nconfig :tableau, Tableau.RSSExtension,\n  enabled: true,\n  language: \"pt-BR\",\n  title: \"My Elixir Devlog\",\n  description: \"My Journey on Becoming the Best Elixirist\"\n```","ref":"Tableau.RSSExtension.html#module-example","title":"Example - Tableau.RSSExtension","type":"module"},{"doc":"","ref":"Tableau.RSSExtension.html#run/1","title":"Tableau.RSSExtension.run/1","type":"function"}]}